using Grasshopper.Kernel;
using Grasshopper.Kernel.Parameters;
using Rhino.Geometry;
using System;

namespace offset
{
    public class OffsetComponent : GH_Component
    {
        public OffsetComponent() : base("offset", "Nickname", "Description", "test", "Offset") { }

        protected override void RegisterInputParams(GH_InputParamManager pManager)
        {
            pManager.AddPlaneParameter("Plane", "P", "Plane", GH_ParamAccess.item, Plane.WorldXY);
            pManager.AddCurveParameter("Curve", "C", "Curve", GH_ParamAccess.item);
            pManager.AddNumberParameter("Distance", "D", "Distance", GH_ParamAccess.item);
            pManager.AddIntegerParameter("Style", "S", "Style", GH_ParamAccess.item);
            var style = (Param_Integer)pManager[3];
            style.AddNamedValue("None", 0);
            style.AddNamedValue("Sharp", 1);
            style.AddNamedValue("Round", 2);
            style.AddNamedValue("Smooth", 3);
            style.AddNamedValue("Chamfer", 4);
        }
        protected override void RegisterOutputParams(GH_OutputParamManager pManager)
        {
            pManager.AddCurveParameter("Curve", "C", "Curve", GH_ParamAccess.list);
        }
        protected override void SolveInstance(IGH_DataAccess da)
        {
            var plane = Plane.Unset;
            Curve curve = null;
            var distance = 0.0;
            var style = 0;
            da.GetData(0, ref plane);
            da.GetData(1, ref curve);
            da.GetData(2, ref distance);
            da.GetData(3, ref style);
            var offset = curve.Offset(plane, distance, DocumentTolerance(), (CurveOffsetCornerStyle)style);
            da.SetDataList(0, offset);
        }
        protected override System.Drawing.Bitmap Icon => null;
        public override Guid ComponentGuid => new Guid("851F9350-8A95-4EBE-8EE1-A6A567974185");
    }
}